﻿// ECMAScript 5 strict mode
"use strict";

assert2(cr, "cr namespace not created");
assert2(cr.plugins_, "cr.plugins_ not created");

/////////////////////////////////////
// Plugin class
cr.plugins_.wtUtc = function(runtime)
{
	this.runtime = runtime;
};

(function ()
{
	var pluginProto = cr.plugins_.wtUtc.prototype;
		
	/////////////////////////////////////
	// Object type class
	pluginProto.Type = function(plugin)
	{
		this.plugin = plugin;
		this.runtime = plugin.runtime;
	};

	var typeProto = pluginProto.Type.prototype;

	typeProto.onCreate = function()
	{
	};

	/////////////////////////////////////
	// Instance class
	pluginProto.Instance = function(type)
	{
		this.type = type;
		this.runtime = type.runtime;
		
		// Initialise object properties
		this.timeZone = 0;
		this.dateSpacer = ".";
		this.endian = "littleEndian";
		this.useLocal = '0';
		this.weekday = ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"];
	};
	
	var instanceProto = pluginProto.Instance.prototype;
	
	instanceProto.onCreate = function()
	{
		// Read properties set in C3
		this.timeZone = this.properties[0];
		this.dateSpacer = this.properties[1];
		this.endian = this.properties[2];
		this.useLocal = this.properties[3];
	};
	
	instanceProto.saveToJSON = function ()
	{
		return {};
	};
	
	instanceProto.loadFromJSON = function (o)
	{
	};
	
	/**BEGIN-PREVIEWONLY**/
	instanceProto.getDebuggerValues = function (propsections)
	{
	};
	/**END-PREVIEWONLY**/

	//////////////////////////////////////
	// Conditions
	function Cnds() {};
	
	pluginProto.cnds = new Cnds();

	//////////////////////////////////////
	// Actions
	function Acts() {};
	
	Acts.prototype.setTimezone = function (utc)
	{
		this.timeZone = utc;
	};
	
	Acts.prototype.setSpacer = function (seperator)
	{
		this.dateSpacer = seperator;
	};
	
	Acts.prototype.setDateFormat = function (endian)
	{
		this.endian = endian;
	};
	
	Acts.prototype.setUseLocal = function (bool)
	{
		if (bool === 0) {
			this.useLocal = true;
		} else {
			this.useLocal = false;
		}
		
		
	};
	
	/*Acts.prototype.setTimezone = function (utc)
	{
		this.timeZone = utc;
	};*/
	
	pluginProto.acts = new Acts();

	//////////////////////////////////////
	// Expressions
	function Exps() {};
	
	// Get current timestamp in milliseconds
	Exps.prototype.currTimestamp = function (ret)
	{
		var date = new Date();
		
		if (this.useLocal === true) {
			var offset = date.getTimezoneOffset() * -1;
			var date = date.getTime() + offset * 60000;
			
			ret.set_int(date);
			
		} else {
			ret.set_int(date.getTime() + 3600000 * this.timeZone);
		}
		
	};
	
	// Get current date String
	Exps.prototype.currDate = function (ret)
	{
		var date = new Date();
		
		if (this.useLocal === true) {
			var offset = date.getTimezoneOffset() * -1;
			var timestamp = new Date(date.getTime() + offset * 60000);
		} else {
			var timestamp = new Date(date.getTime() + 3600000 * this.timeZone);
		}
		
		switch(this.endian) {
			case 0:
				var date = String(timestamp.getUTCDate())["padStart"](2, '0') + this.dateSpacer + String(timestamp.getUTCMonth()+1)["padStart"](2, '0') + this.dateSpacer + timestamp.getUTCFullYear();
				break;
			case 1:
				var date = String(timestamp.getUTCMonth()+1)["padStart"](2, '0') + this.dateSpacer + String(timestamp.getUTCDate())["padStart"](2, '0') + this.dateSpacer + timestamp.getUTCFullYear();
				break;
			case 2:
				var date = String(timestamp.getUTCFullYear()) + this.dateSpacer + String(timestamp.getUTCMonth()+1)["padStart"](2, '0') + this.dateSpacer + String(timestamp.getUTCDate())["padStart"](2, '0');
				break;
			default:
				var date = String(timestamp.getUTCDate())["padStart"](2, '0') + this.dateSpacer + String(timestamp.getUTCMonth()+1)["padStart"](2, '0') + this.dateSpacer + timestamp.getUTCFullYear();
				break;
		}
		
		
		ret.set_string(date);
	};
	
	Exps.prototype.currTime = function (ret, level)
	{
		var date = new Date();
		
		if (this.useLocal === true) {
			var offset = date.getTimezoneOffset() * -1;
			var timestamp = new Date(date.getTime() + offset * 60000); 
		} else {
			var timestamp = new Date(date.getTime() + 3600000 * this.timeZone);
		}
		
		switch(level) {
			case "millisecond":
				var time = String(timestamp.getUTCHours())["padStart"](2, '0') + ":" + String(timestamp.getUTCMinutes())["padStart"](2, '0') + ":" + String(timestamp.getUTCSeconds())["padStart"](2, '0') + ":" + String(timestamp.getUTCMilliseconds())["padStart"](3, '0');
				break;
			case "second":
				var time = String(timestamp.getUTCHours())["padStart"](2, '0') + ":" + String(timestamp.getUTCMinutes())["padStart"](2, '0') + ":" + String(timestamp.getUTCSeconds())["padStart"](2, '0');
				break;
			case "minute":
				var time = String(timestamp.getUTCHours())["padStart"](2, '0') + ":" + String(timestamp.getUTCMinutes())["padStart"](2, '0');
				break;
			default:
				var time = String(timestamp.getUTCHours())["padStart"](2, '0') + ":" + String(timestamp.getUTCMinutes())["padStart"](2, '0');
				break;
		}
		
		
		ret.set_string(time);
	};
	
	Exps.prototype.milliseconds = function (ret)
	{
		var date = new Date();
		ret.set_int(date.getUTCMilliseconds());
	};
	
	Exps.prototype.seconds = function (ret)
	{
		var date = new Date();
		ret.set_int(date.getUTCSeconds());
	};
	
	Exps.prototype.minutes = function (ret)
	{
		var date = new Date();
		ret.set_int(date.getUTCMinutes());
	};
	
	Exps.prototype.hours = function (ret)
	{
		var date = new Date();
		var offset = date.getTimezoneOffset() * -1;
		
		var timestamp = new Date(date.getTime() + 3600000 * this.timeZone);
		if (this.useLocal === true) timestamp = new Date(date.getTime() + 60000 * offset);
		
		ret.set_int(timestamp.getUTCHours());
	};
	
	Exps.prototype.day = function (ret)
	{
		var date = new Date();
		var offset = date.getTimezoneOffset() * -1;
		
		var timestamp = new Date(date.getTime() + 3600000 * this.timeZone);
		if (this.useLocal === true) timestamp = new Date(date.getTime() + 60000 * offset);
		
		ret.set_int(timestamp.getUTCDate());
	};
	
	Exps.prototype.weekday = function (ret)
	{
		var date = new Date();
		var offset = date.getTimezoneOffset() * -1;
		
		var timestamp = new Date(date.getTime() + 3600000 * this.timeZone);
		if (this.useLocal === true) timestamp = new Date(date.getTime() + 60000 * offset);
		timestamp = timestamp.getUTCDay();
		
		ret.set_string(this.weekday[timestamp]);
	};
	
	Exps.prototype.month = function (ret)
	{
		var date = new Date();
		var offset = date.getTimezoneOffset() * -1;
		
		var timestamp = new Date(date.getTime() + 3600000 * this.timeZone);
		if (this.useLocal === true) timestamp = new Date(date.getTime() + 60000 * offset);
		
		ret.set_int(timestamp.getUTCMonth()+1);
	};
	
	Exps.prototype.year = function (ret)
	{
		var date = new Date();
		var offset = date.getTimezoneOffset() * -1;
		
		var timestamp = new Date(date.getTime() + 3600000 * this.timeZone);
		if (this.useLocal === true) timestamp = new Date(date.getTime() + 60000 * offset);
		
		ret.set_int(timestamp.getUTCFullYear());
	};
	
	Exps.prototype.durationStamp = function (ret, days, months, years, hours, minutes, seconds, milliseconds)
	{
		var ms = milliseconds;
		var s = seconds * 1000;
		var m = minutes * 60000;
		var h = hours * 3600000;
		var d = days * 86400000;
		var mo = months * 2628000000;
		var y = years * 31536000000;
		
		var date = new Date();
		var offset = date.getTimezoneOffset() * -1;
		
		var timestamp = date.getTime() + 3600000 * this.timeZone;
		if (this.useLocal === true) timestamp = date.getTime() + 60000 * offset;
		
		var timestamp = timestamp + ms + s + m + h + d + mo + y;
		
		ret.set_int(timestamp);
	};
	
	Exps.prototype.dateStamp = function (ret, days, months, years, hours, minutes, seconds, milliseconds)
	{
		var date = String(months + " " + days + " " + years + " " + hours + ":" + minutes + ":" + seconds + ":" + milliseconds);
		
		var date = new Date(date);
		var offset = new Date().getTimezoneOffset() * -1;
		var timestamp = date.getTime() + 3600000 * this.timeZone;
		if (this.useLocal === true) timestamp = date.getTime() + 60000 * offset;
		
		ret.set_int(timestamp);
	};
	
	
	pluginProto.exps = new Exps();

}());